@@ -1,6 +1,6 @@
 /* Basic type operations for S-Lang */
 /*
-Copyright (C) 2004-2010 John E. Davis
+Copyright (C) 2004-2011 John E. Davis
 
 This file is part of the S-Lang Library.
 
@@ -442,7 +442,7 @@ int _pSLstring_list_push (_pSLString_List_Type *p, int delete_list)
 
 int _pSLstring_list_init (_pSLString_List_Type *p, unsigned int max_num, unsigned int delta_num)
 {
-   if (NULL == (p->buf = (char **) SLmalloc (max_num * sizeof (char *))))
+   if (NULL == (p->buf = (char **) _SLcalloc (max_num, sizeof (char *))))
      return -1;
 
    p->max_num = max_num;
